@@ -1,6 +1,7 @@
 import os
 import json
 import abc
+import shutil
 from zipfile import ZipFile
 from click import Path as ClickPath, UsageError
 from clint.textui import progress
@@ -16,7 +17,7 @@ from .models import FileRef, Output
 
 
 class BaseModule(abc.ABC, Cli):
-    OUTPUT_FILENAME: str = "outputs.json"
+    OUTPUT_FILENAME: str = os.getenv("OUTPUT_FILENAME", "outputs.json")
     CHUNK_SIZE: int = 2391975
 
     @abc.abstractmethod
@@ -47,19 +48,21 @@ class BaseModule(abc.ABC, Cli):
         outfile_path = os.path.join(artifact_path, self.OUTPUT_FILENAME)
         with open(outfile_path, "w") as outfile:
             outfile.write(output.output_json + "\n")
-            logger.info(f"Output saved to {outfile_path}")
+            logger.info(f"Output JSON saved to {outfile_path}")
 
         if output.files is not None:
-            zip_path = os.path.join(artifact_path, "files.zip")
-            logger.info("Creating output files zip: {zip_path}")
             to_zip = []
+            logger.info(f"Ensuring output files are in correct folder: {artifact_path}")
             for _file in output.files:
                 target = Path(os.path.join(artifact_path, f"{_file.name}"))
                 if not target.exists() and _file.path is not None:
-                    Path(_file.path).rename(target)
+                    logger.info(f"Moving {_file.path} to {target}")
+                    shutil.move(_file.path, target)
                 to_zip.append({"path": str(target), "name": f"{_file.name}"})
 
             if zip:
+                zip_path = os.path.join(artifact_path, "files.zip")
+                logger.info(f"Creating output files zip: {zip_path}")
                 with ZipFile(zip_path, "w") as zipObj:
                     for zf in to_zip:
                         zipObj.write(zf["path"], zf["name"])
